pub trait MevFullApiClient: ClientT {
// Provided methods
fn send_bundle(
&self,
request: MevSendBundle,
) -> impl Future<Output = Result<EthBundleHash, Error>> + Send { ... }
fn sim_bundle(
&self,
bundle: MevSendBundle,
sim_overrides: SimBundleOverrides,
) -> impl Future<Output = Result<SimBundleResponse, Error>> + Send { ... }
}Available on crate features
client and rpc only.Expand description
Client implementation for the MevFullApi RPC API.
Provided Methods
Sourcefn send_bundle(
&self,
request: MevSendBundle,
) -> impl Future<Output = Result<EthBundleHash, Error>> + Send
fn send_bundle( &self, request: MevSendBundle, ) -> impl Future<Output = Result<EthBundleHash, Error>> + Send
Submitting bundles to the relay. It takes in a bundle and provides a bundle hash as a return value.
Sourcefn sim_bundle(
&self,
bundle: MevSendBundle,
sim_overrides: SimBundleOverrides,
) -> impl Future<Output = Result<SimBundleResponse, Error>> + Send
fn sim_bundle( &self, bundle: MevSendBundle, sim_overrides: SimBundleOverrides, ) -> impl Future<Output = Result<SimBundleResponse, Error>> + Send
Similar to mev_sendBundle but instead of submitting a bundle to the relay, it returns
a simulation result. Only fully matched bundles can be simulated.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".