pub trait RethEngineApiClient<ExecutionData>: ClientT{
// Provided methods
fn reth_new_payload(
&self,
payload: RethNewPayloadInput<ExecutionData>,
) -> impl Future<Output = Result<RethPayloadStatus, Error>> + Send { ... }
fn reth_forkchoice_updated(
&self,
forkchoice_state: ForkchoiceState,
) -> impl Future<Output = Result<ForkchoiceUpdated, Error>> + Send { ... }
}Available on crate feature
client only.Expand description
Client implementation for the RethEngineApi RPC API.
Provided Methods
Sourcefn reth_new_payload(
&self,
payload: RethNewPayloadInput<ExecutionData>,
) -> impl Future<Output = Result<RethPayloadStatus, Error>> + Send
fn reth_new_payload( &self, payload: RethNewPayloadInput<ExecutionData>, ) -> impl Future<Output = Result<RethPayloadStatus, Error>> + Send
Reth-specific newPayload that accepts either ExecutionData directly or an RLP-encoded
block.
Waits for persistence, execution cache, and sparse trie locks before processing.
Sourcefn reth_forkchoice_updated(
&self,
forkchoice_state: ForkchoiceState,
) -> impl Future<Output = Result<ForkchoiceUpdated, Error>> + Send
fn reth_forkchoice_updated( &self, forkchoice_state: ForkchoiceState, ) -> impl Future<Output = Result<ForkchoiceUpdated, Error>> + Send
Reth-specific forkchoiceUpdated that sends a regular forkchoice update with no payload attributes.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.